@@ -2,7 +2,11 @@ import math
 import pprint
 
 import numpy as np
-import pydantic
+
+try:
+    import pydantic.v1 as pydantic
+except ImportError:  # Will also trap ModuleNotFoundError
+    import pydantic
 import pytest
 
 import qcelemental as qcel
@@ -572,7 +576,6 @@ def test_vector_gradient_align():
     ],
 )
 def test_guess_connectivity(args, kwargs, ans):
-
     computed = qcel.molutil.guess_connectivity(*args, **kwargs)
     assert compare(computed, ans)
 
