@@ -1,7 +1,11 @@
 from decimal import Decimal
 
 import numpy as np
-import pydantic
+
+try:
+    import pydantic.v1 as pydantic
+except ImportError:  # Will also trap ModuleNotFoundError
+    import pydantic
 import pytest
 
 import qcelemental as qcel
